@@ -4,12 +4,12 @@ from hypothesis.extra.django import from_model
 from basxconnect.core import models
 
 
-class CategoryTest(generic_bread_testcase(models.Category)):
+class VocabularyTest(generic_bread_testcase(models.Vocabulary)):
     pass
 
 
 class TermTest(
-    generic_bread_testcase(models.Term, category=from_model(models.Category))
+    generic_bread_testcase(models.Term, vocabulary=from_model(models.Vocabulary))
 ):
     pass
 
